summary refs log tree commit diff
path: root/pkgs/development/libraries/libffi/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/development/libraries/libffi/default.nix')
-rw-r--r--pkgs/development/libraries/libffi/default.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkgs/development/libraries/libffi/default.nix b/pkgs/development/libraries/libffi/default.nix
index 807fe54c27e8..9db9b801952e 100644
--- a/pkgs/development/libraries/libffi/default.nix
+++ b/pkgs/development/libraries/libffi/default.nix
@@ -12,13 +12,13 @@ stdenv.mkDerivation rec {
 
   configureFlags = [ "--with-gcc-arch=generic" ]; # no detection of -march= or -mtune=
 
-  doCheck = !stdenv.isDarwin; # until we solve dejagnu problems on darwin
+  doCheck = stdenv.isLinux; # until we solve dejagnu problems on darwin and expect on BSD
 
   dontStrip = stdenv ? cross; # Don't run the native `strip' when cross-compiling.
 
   postInstall =
     # Install headers in the right place.
-    '' ln -srv "$out/lib/"libffi*/include "$out/include"
+    '' ln -s${if stdenv.isFreeBSD then "" else "r"}v "$out/lib/"libffi*/include "$out/include"
     '';
 
   meta = {